﻿/*=================================================================================================================

■2枚目に支援相手一覧

〇概要
　ユニットメニューウィンドウの2枚目に支援相手を表示するスクリプトです。
　これにより、最大11人までの支援相手をユニットメニューウィンドウから飛び出ることなく表示できます。 

〇こんなときに使います
　デフォルトのままだと支援相手が多いと支援相手がウィンドウを飛びぬけて表示されてしまいます。
　また、フュージョンをしたりステート変化があったりすると同じく飛びぬけることがあります。
　これが見た目的に嫌だな、という場合にお使いください。

〇使い方
　この「2枚目に支援相手一覧.js」をプロジェクトファイルの「Plugin」フォルダに入れてください。

〇注意
　同梱の「既存支援相手一覧を削除.js」はお好みで導入（プロジェクトファイルの「Plugin」フォルダに入れる）してください。
　既存のユニットメニューウィンドウの右側の「支援相手」を削除します。

〇改変に関する表記
　このスクリプトは「名前未定（仮）」様の「2枚目に付与ステートを表示するスクリプト」を改変したものです。

〇履歴
　2016/05/25 公開
　2017/06/24 更新（配布のため、このコメント欄を追加）

〇対応バージョン
　SRPG Studio Version:1.129

〇連絡先
　・シルバーティアラの行方 - お問い合わせフォーム		https://silvertiara.click/other/contact
　・レリーズ（シルバーティアラの行方作者）titterアカウント	https://twitter.com/ReleaseCarte

〇利用規約
　改変：OK
　改変したものを公開：OK
　再配布：OK
　商用での使用：OK
　作成者の偽り：NG
　著作権表記：必要ありません（記載したいという場合は「Release」または「レリーズ」でお願いします）
　作成者を偽らなければ基本的に全部OKです。

〇余談
　1列11人しか表示しません。無駄なスペースが多く、ご希望があれば2列目とかも作るかもです、、、

=================================================================================================================*/

(function() {

var alias1 = UnitMenuScreen._configureBottomWindows;
UnitMenuScreen._configureBottomWindows = function(groupArray) {
	alias1.call(this, groupArray);
	
	groupArray.appendWindowObject(UnitMenuBottomSecondWindow, this);
};

var UnitMenuBottomSecondWindow = defineObject(BaseWindow,
{
	setUnitMenuData: function() {
	},
	
	changeUnitMenuTarget: function(unit) {
		UnitMenuTopWindow._unit = unit;
	},
	
	moveWindowContent: function() {
		return MoveResult.CONTINUE;
	},
	
	drawWindowContent: function(x, y) {

		var i;
		var textui   = this.getWindowTextUI();
		var font     = textui.getFont();
		var sp_title = '支援相手一覧';	//支援相手ページのタイトル

		//ユニットを取得
		var now_unit = UnitMenuTopWindow._unit;

		//支援相手ページのタイトルの描画
		TextRenderer.drawText(x, y-8, sp_title, -1, ColorValue.KEYWORD, font);

		//支援相手の数をカウントしcountに代入
                var count = now_unit.getSupportDataCount();

		for (i = 0; i < count; i++) {
			data = now_unit.getSupportData(i);
			targetUnit = data.getUnit();
			if (targetUnit !== null && data.isGlobalSwitchOn() && data.isVariableOn()) {
				TextRenderer.drawKeywordText(x, y+10, targetUnit.getName(), -1, ColorValue.KEYWORD, font);
				y += 17;
			}
		}
	},
	
	getWindowWidth: function() {
		return 450;
	},
	
	getWindowHeight: function() {
		return DefineControl.getUnitMenuBottomWindowHeight();
	},
	
	setHelpMode: function() {
		return false;
	},
	
	isHelpMode: function() {
		return false;
	},
	
	isTracingHelp: function() {
		return false;
	},
	
	getHelpText: function() {
		return '';
	}
}
);

})();
